==> zio-aws-timestreamwrite_2.12-5.17.129.1-sources.jar: zio/aws/timestreamwrite/model/S3Configuration.scala <==
package zio.aws.timestreamwrite.model
import zio.aws.timestreamwrite.model.primitives.{
  StringValue2048,
  S3ObjectKeyPrefix,
  S3BucketName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class S3Configuration(
    bucketName: Option[S3BucketName] = None,
    objectKeyPrefix: Option[S3ObjectKeyPrefix] = None,
    encryptionOption: Option[zio.aws.timestreamwrite.model.S3EncryptionOption] =
      None,
    kmsKeyId: Option[StringValue2048] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.S3Configuration = {
    import S3Configuration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
      .builder()
      .optionallyWith(
        bucketName.map(value => S3BucketName.unwrap(value): java.lang.String)
      )(_.bucketName)
      .optionallyWith(
        objectKeyPrefix.map(value =>
          S3ObjectKeyPrefix.unwrap(value): java.lang.String
        )
      )(_.objectKeyPrefix)
      .optionallyWith(encryptionOption.map(value => value.unwrap))(
        _.encryptionOption
      )
      .optionallyWith(
        kmsKeyId.map(value => StringValue2048.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.S3Configuration.ReadOnly =
    zio.aws.timestreamwrite.model.S3Configuration.wrap(buildAwsValue())
}
object S3Configuration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.S3Configuration =
      zio.aws.timestreamwrite.model.S3Configuration(
        bucketName.map(value => value),
        objectKeyPrefix.map(value => value),
        encryptionOption.map(value => value),
        kmsKeyId.map(value => value)
      )
    def bucketName: Option[S3BucketName]
    def objectKeyPrefix: Option[S3ObjectKeyPrefix]
    def encryptionOption
        : Option[zio.aws.timestreamwrite.model.S3EncryptionOption]
    def kmsKeyId: Option[StringValue2048]
    def getBucketName: ZIO[Any, AwsError, S3BucketName] =
      AwsError.unwrapOptionField("bucketName", bucketName)
    def getObjectKeyPrefix: ZIO[Any, AwsError, S3ObjectKeyPrefix] =
      AwsError.unwrapOptionField("objectKeyPrefix", objectKeyPrefix)
    def getEncryptionOption
        : ZIO[Any, AwsError, zio.aws.timestreamwrite.model.S3EncryptionOption] =
      AwsError.unwrapOptionField("encryptionOption", encryptionOption)
    def getKmsKeyId: ZIO[Any, AwsError, StringValue2048] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
  ) extends zio.aws.timestreamwrite.model.S3Configuration.ReadOnly {
    override val bucketName: Option[S3BucketName] = scala
      .Option(impl.bucketName())
      .map(value =>
        zio.aws.timestreamwrite.model.primitives.S3BucketName(value)
      )
    override val objectKeyPrefix: Option[S3ObjectKeyPrefix] = scala
      .Option(impl.objectKeyPrefix())
      .map(value =>
        zio.aws.timestreamwrite.model.primitives.S3ObjectKeyPrefix(value)
      )
    override val encryptionOption
        : Option[zio.aws.timestreamwrite.model.S3EncryptionOption] = scala
      .Option(impl.encryptionOption())
      .map(value =>
        zio.aws.timestreamwrite.model.S3EncryptionOption.wrap(value)
      )
    override val kmsKeyId: Option[StringValue2048] = scala
      .Option(impl.kmsKeyId())
      .map(value =>
        zio.aws.timestreamwrite.model.primitives.StringValue2048(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
  ): zio.aws.timestreamwrite.model.S3Configuration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-timestreamwrite_2.12-5.17.205.1-sources.jar: zio/aws/timestreamwrite/model/S3Configuration.scala <==
package zio.aws.timestreamwrite.model
import zio.aws.timestreamwrite.model.primitives.{
  StringValue2048,
  S3ObjectKeyPrefix,
  S3BucketName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class S3Configuration(
    bucketName: Optional[S3BucketName] = Optional.Absent,
    objectKeyPrefix: Optional[S3ObjectKeyPrefix] = Optional.Absent,
    encryptionOption: Optional[
      zio.aws.timestreamwrite.model.S3EncryptionOption
    ] = Optional.Absent,
    kmsKeyId: Optional[StringValue2048] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.S3Configuration = {
    import S3Configuration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
      .builder()
      .optionallyWith(
        bucketName.map(value => S3BucketName.unwrap(value): java.lang.String)
      )(_.bucketName)
      .optionallyWith(
        objectKeyPrefix.map(value =>
          S3ObjectKeyPrefix.unwrap(value): java.lang.String
        )
      )(_.objectKeyPrefix)
      .optionallyWith(encryptionOption.map(value => value.unwrap))(
        _.encryptionOption
      )
      .optionallyWith(
        kmsKeyId.map(value => StringValue2048.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.S3Configuration.ReadOnly =
    zio.aws.timestreamwrite.model.S3Configuration.wrap(buildAwsValue())
}
object S3Configuration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.S3Configuration =
      zio.aws.timestreamwrite.model.S3Configuration(
        bucketName.map(value => value),
        objectKeyPrefix.map(value => value),
        encryptionOption.map(value => value),
        kmsKeyId.map(value => value)
      )
    def bucketName: Optional[S3BucketName]
    def objectKeyPrefix: Optional[S3ObjectKeyPrefix]
    def encryptionOption
        : Optional[zio.aws.timestreamwrite.model.S3EncryptionOption]
    def kmsKeyId: Optional[StringValue2048]
    def getBucketName: ZIO[Any, AwsError, S3BucketName] =
      AwsError.unwrapOptionField("bucketName", bucketName)
    def getObjectKeyPrefix: ZIO[Any, AwsError, S3ObjectKeyPrefix] =
      AwsError.unwrapOptionField("objectKeyPrefix", objectKeyPrefix)
    def getEncryptionOption
        : ZIO[Any, AwsError, zio.aws.timestreamwrite.model.S3EncryptionOption] =
      AwsError.unwrapOptionField("encryptionOption", encryptionOption)
    def getKmsKeyId: ZIO[Any, AwsError, StringValue2048] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
  ) extends zio.aws.timestreamwrite.model.S3Configuration.ReadOnly {
    override val bucketName: Optional[S3BucketName] = zio.aws.core.internal
      .optionalFromNullable(impl.bucketName())
      .map(value =>
        zio.aws.timestreamwrite.model.primitives.S3BucketName(value)
      )
    override val objectKeyPrefix: Optional[S3ObjectKeyPrefix] =
      zio.aws.core.internal
        .optionalFromNullable(impl.objectKeyPrefix())
        .map(value =>
          zio.aws.timestreamwrite.model.primitives.S3ObjectKeyPrefix(value)
        )
    override val encryptionOption
        : Optional[zio.aws.timestreamwrite.model.S3EncryptionOption] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionOption())
        .map(value =>
          zio.aws.timestreamwrite.model.S3EncryptionOption.wrap(value)
        )
    override val kmsKeyId: Optional[StringValue2048] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKeyId())
      .map(value =>
        zio.aws.timestreamwrite.model.primitives.StringValue2048(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.S3Configuration
  ): zio.aws.timestreamwrite.model.S3Configuration.ReadOnly = new Wrapper(impl)
}
